@@ -21,8 +21,6 @@
 #include "moc_kstandardaction_p.cpp"
 #include "kconfigwidgets_debug.h"
 
-#include <QMutableStringListIterator>
-#include <QToolButton>
 
 #include <QApplication>
 #include <QLayout>
@@ -168,9 +166,11 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
         case Home:
             sLabel = i18nc("home page", "&Home");
             break;
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 23)
         case Help:
             sLabel = i18nc("show help", "&Help");
             break;
+#endif
         case Preferences:
         case AboutApp:
         case HelpContents: {
@@ -197,6 +197,13 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
             }
         }
 
+        if (id == Donate) {
+            const QString currencyCode = QLocale().currencySymbol(QLocale::CurrencyIsoCode).toLower();
+            if (!currencyCode.isEmpty()) {
+                iconName = QStringLiteral("help-donate-%1").arg(currencyCode);
+            }
+        }
+
         QIcon icon = iconName.isEmpty() ? QIcon() : QIcon::fromTheme(iconName);
 
         switch (id) {
@@ -234,7 +241,7 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
             pAction = new KToggleFullScreenAction(parent);
             pAction->setCheckable(true);
             break;
-#if !defined(KDE_NO_DEPRECATED) && defined(QT_DBUS_LIB)
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 39) && defined(QT_DBUS_LIB)
         case PasteText:
             pAction = new KPasteTextAction(parent);
             break;
@@ -244,12 +251,19 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
         {
             pAction = new QAction(parent);
             icon = qApp->windowIcon();
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
+            // Using deprecated API for compatibility reasons, remove with KF6
             if (icon.isNull()) {
                 const KAboutData data = KAboutData::applicationData();
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
                 if (!data.programIconName().isEmpty()) {
                     icon = QIcon::fromTheme(data.programIconName());
+QT_WARNING_POP
                 }
             }
+#endif
             break;
         }
 
@@ -405,7 +419,7 @@ QAction *paste(const QObject *recvr, const char *slot, QObject *parent)
     return KStandardAction::create(Paste, recvr, slot, parent);
 }
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 39)
 QAction *pasteText(const QObject *recvr, const char *slot, QObject *parent)
 {
     return KStandardAction::create(PasteText, recvr, slot, parent);
@@ -641,7 +655,7 @@ KToggleFullScreenAction *fullScreen(const QObject *recvr, const char *slot, QWid
     return ret;
 }
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 38)
 QAction *saveOptions(const QObject *recvr, const char *slot, QObject *parent)
 {
     return KStandardAction::create(SaveOptions, recvr, slot, parent);
@@ -668,7 +682,7 @@ QAction *configureNotifications(const QObject *recvr, const char *slot, QObject
     return KStandardAction::create(ConfigureNotifications, recvr, slot, parent);
 }
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 38)
 QAction *help(const QObject *recvr, const char *slot, QObject *parent)
 {
     return KStandardAction::create(Help, recvr, slot, parent);
